ScreenshotShieldPlatform class abstract
The interface that platform implementations of screenshot_shield must
extend.
- Inheritance
-
- Object
- PlatformInterface
- ScreenshotShieldPlatform
Constructors
- ScreenshotShieldPlatform()
- Constructs a ScreenshotShieldPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onScreenshotDetected
→ Stream<
void> -
Emits an event each time the user captures a screenshot.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Releases the native resources held by the plugin.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setBackgroundBlur(
{required bool blurEnabled}) → Future< void> - Blurs the app content while the app is in the background.
-
setProtected(
{required bool protected}) → Future< void> - Prevents screen capture on Android. No-op on iOS.
-
startListening(
) → Future< void> - Starts observing for screenshots.
-
stopListening(
) → Future< void> - Stops observing for screenshots.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ ScreenshotShieldPlatform
-
The default instance of ScreenshotShieldPlatform to use.
getter/setter pair